@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2006-2009 Bjorn Andersson <flex@kryo.se>, Erik Ekman <yarrick@kryo.se>
+ * Copyright (c) 2006-2007 Bjorn Andersson <flex@kryo.se>, Erik Ekman <yarrick@kryo.se>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -15,14 +15,8 @@
  */
 
 #include <string.h>
-#include <sys/types.h>
-
-#ifdef WINDOWS32
-#include "windows.h"
-#else
-#include <netinet/in.h>
 #include <arpa/inet.h>
-#endif
+#include <sys/types.h>
 
 #include "md5.h"
 
@@ -30,7 +24,7 @@
  * Needs a 16byte array for output, and 32 bytes password 
  */
 void 
-login_calculate(char *buf, int buflen, const char *pass, int seed) 
+login_calculate(char *buf, int buflen, char *pass, int seed) 
 {
 	unsigned char temp[32];
 	md5_state_t ctx;
