@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2006-2009 Bjorn Andersson <flex@kryo.se>, Erik Ekman <yarrick@kryo.se>
+ * Copyright (c) 2006-2007 Bjorn Andersson <flex@kryo.se>, Erik Ekman <yarrick@kryo.se>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -19,8 +19,8 @@
 #include <string.h>
 #include <time.h>
 #include <sys/socket.h>
-#include <netinet/in.h>
 #include <arpa/inet.h>
+#include <netinet/in.h>
 
 #include "common.h"
 #include "encoding.h"
@@ -32,11 +32,10 @@ START_TEST(test_init_users)
 	in_addr_t ip;
 	char givenip[16];
 	int i;
-	int count;
 
 	ip = inet_addr("127.0.0.1");
-	count = init_users(ip, 27);
-	for (i = 0; i < count; i++) {
+	init_users(ip);
+	for (i = 0; i < USERS; i++) {
 		fail_unless(users[i].id == i);
 		fail_unless(users[i].q.id == 0);
 		fail_unless(users[i].inpacket.len == 0);
@@ -52,7 +51,7 @@ START_TEST(test_users_waiting)
 	in_addr_t ip;
 
 	ip = inet_addr("127.0.0.1");
-	init_users(ip, 27);
+	init_users(ip);
 
 	fail_unless(users_waiting_on_reply() == 0);
 
@@ -64,7 +63,6 @@ START_TEST(test_users_waiting)
 	
 	fail_unless(users_waiting_on_reply() == 0);
 	
-	users[3].conn = CONN_DNS_NULL;
 	users[3].q.id = 1;
 	
 	fail_unless(users_waiting_on_reply() == 1);
@@ -77,8 +75,7 @@ START_TEST(test_find_user_by_ip)
 	unsigned int testip;
 
 	ip = inet_addr("127.0.0.1");
-	init_users(ip, 27);
-	users[0].conn = CONN_DNS_NULL;
+	init_users(ip);
 
 	testip = (unsigned int) inet_addr("10.0.0.1");
 	fail_unless(find_user_by_ip(testip) == -1);
@@ -103,25 +100,19 @@ START_TEST(test_all_users_waiting_to_send)
 	in_addr_t ip;
 
 	ip = inet_addr("127.0.0.1");
-	init_users(ip, 27);
+	init_users(ip);
 
 	fail_unless(all_users_waiting_to_send() == 1);
 	
-	users[0].conn = CONN_DNS_NULL;
 	users[0].active = 1;
 	
 	fail_unless(all_users_waiting_to_send() == 1);
 	
 	users[0].last_pkt = time(NULL);
-	users[0].outpacket.len = 0;
 	
 	fail_unless(all_users_waiting_to_send() == 0);
 
-#ifdef OUTPACKETQ_LEN
-	users[0].outpacketq_filled = 1;
-#else
 	users[0].outpacket.len = 44;
-#endif
 	
 	fail_unless(all_users_waiting_to_send() == 1);
 }
@@ -133,7 +124,7 @@ START_TEST(test_find_available_user)
 	int i;
 
 	ip = inet_addr("127.0.0.1");
-	init_users(ip, 27);
+	init_users(ip);
 
 	for (i = 0; i < USERS; i++) {
 		fail_unless(find_available_user() == i);
@@ -155,34 +146,6 @@ START_TEST(test_find_available_user)
 }
 END_TEST
 
-START_TEST(test_find_available_user_small_net)
-{
-	in_addr_t ip;
-	int i;
-
-	ip = inet_addr("127.0.0.1");
-	init_users(ip, 29); /* this should result in 5 enabled users */
-
-	for (i = 0; i < 5; i++) {
-		fail_unless(find_available_user() == i);
-	}
-
-	for (i = 0; i < USERS; i++) {
-		fail_unless(find_available_user() == -1);
-	}
-
-	users[3].active = 0;
-
-	fail_unless(find_available_user() == 3);
-	fail_unless(find_available_user() == -1);
-
-	users[3].last_pkt = 55;
-	
-	fail_unless(find_available_user() == 3);
-	fail_unless(find_available_user() == -1);
-}
-END_TEST
-
 TCase *
 test_user_create_tests()
 {
@@ -194,7 +157,6 @@ test_user_create_tests()
 	tcase_add_test(tc, test_find_user_by_ip);
 	tcase_add_test(tc, test_all_users_waiting_to_send);
 	tcase_add_test(tc, test_find_available_user);
-	tcase_add_test(tc, test_find_available_user_small_net);
 
 	return tc;
 }
